==> kubernetes-model-apiextensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourceScaleFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface CustomResourceSubresourceScaleFluent<A extends CustomResourceSubresourceScaleFluent<A>> extends Fluent<A> {


    public String getLabelSelectorPath();
    public A withLabelSelectorPath(String labelSelectorPath);
    public Boolean hasLabelSelectorPath();
    public A withNewLabelSelectorPath(StringBuilder arg1);
    public A withNewLabelSelectorPath(int[] arg1,int arg2,int arg3);
    public A withNewLabelSelectorPath(char[] arg1);
    public A withNewLabelSelectorPath(StringBuffer arg1);
    public A withNewLabelSelectorPath(byte[] arg1,int arg2);
    public A withNewLabelSelectorPath(byte[] arg1);
    public A withNewLabelSelectorPath(char[] arg1,int arg2,int arg3);
    public A withNewLabelSelectorPath(byte[] arg1,int arg2,int arg3);
    public A withNewLabelSelectorPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLabelSelectorPath(String arg1);
    public String getSpecReplicasPath();
    public A withSpecReplicasPath(String specReplicasPath);
    public Boolean hasSpecReplicasPath();
    public A withNewSpecReplicasPath(StringBuilder arg1);
    public A withNewSpecReplicasPath(int[] arg1,int arg2,int arg3);
    public A withNewSpecReplicasPath(char[] arg1);
    public A withNewSpecReplicasPath(StringBuffer arg1);
    public A withNewSpecReplicasPath(byte[] arg1,int arg2);
    public A withNewSpecReplicasPath(byte[] arg1);
    public A withNewSpecReplicasPath(char[] arg1,int arg2,int arg3);
    public A withNewSpecReplicasPath(byte[] arg1,int arg2,int arg3);
    public A withNewSpecReplicasPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSpecReplicasPath(String arg1);
    public String getStatusReplicasPath();
    public A withStatusReplicasPath(String statusReplicasPath);
    public Boolean hasStatusReplicasPath();
    public A withNewStatusReplicasPath(StringBuilder arg1);
    public A withNewStatusReplicasPath(int[] arg1,int arg2,int arg3);
    public A withNewStatusReplicasPath(char[] arg1);
    public A withNewStatusReplicasPath(StringBuffer arg1);
    public A withNewStatusReplicasPath(byte[] arg1,int arg2);
    public A withNewStatusReplicasPath(byte[] arg1);
    public A withNewStatusReplicasPath(char[] arg1,int arg2,int arg3);
    public A withNewStatusReplicasPath(byte[] arg1,int arg2,int arg3);
    public A withNewStatusReplicasPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStatusReplicasPath(String arg1);
}

==> kubernetes-model-apiextensions-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourceScaleFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface CustomResourceSubresourceScaleFluent<A extends CustomResourceSubresourceScaleFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getLabelSelectorPath();
    public A withLabelSelectorPath(String labelSelectorPath);
    public Boolean hasLabelSelectorPath();
    public A withNewLabelSelectorPath(StringBuilder arg1);
    public A withNewLabelSelectorPath(int[] arg1,int arg2,int arg3);
    public A withNewLabelSelectorPath(char[] arg1);
    public A withNewLabelSelectorPath(StringBuffer arg1);
    public A withNewLabelSelectorPath(byte[] arg1,int arg2);
    public A withNewLabelSelectorPath(byte[] arg1);
    public A withNewLabelSelectorPath(char[] arg1,int arg2,int arg3);
    public A withNewLabelSelectorPath(byte[] arg1,int arg2,int arg3);
    public A withNewLabelSelectorPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLabelSelectorPath(String arg1);
    public String getSpecReplicasPath();
    public A withSpecReplicasPath(String specReplicasPath);
    public Boolean hasSpecReplicasPath();
    public A withNewSpecReplicasPath(StringBuilder arg1);
    public A withNewSpecReplicasPath(int[] arg1,int arg2,int arg3);
    public A withNewSpecReplicasPath(char[] arg1);
    public A withNewSpecReplicasPath(StringBuffer arg1);
    public A withNewSpecReplicasPath(byte[] arg1,int arg2);
    public A withNewSpecReplicasPath(byte[] arg1);
    public A withNewSpecReplicasPath(char[] arg1,int arg2,int arg3);
    public A withNewSpecReplicasPath(byte[] arg1,int arg2,int arg3);
    public A withNewSpecReplicasPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSpecReplicasPath(String arg1);
    public String getStatusReplicasPath();
    public A withStatusReplicasPath(String statusReplicasPath);
    public Boolean hasStatusReplicasPath();
    public A withNewStatusReplicasPath(StringBuilder arg1);
    public A withNewStatusReplicasPath(int[] arg1,int arg2,int arg3);
    public A withNewStatusReplicasPath(char[] arg1);
    public A withNewStatusReplicasPath(StringBuffer arg1);
    public A withNewStatusReplicasPath(byte[] arg1,int arg2);
    public A withNewStatusReplicasPath(byte[] arg1);
    public A withNewStatusReplicasPath(char[] arg1,int arg2,int arg3);
    public A withNewStatusReplicasPath(byte[] arg1,int arg2,int arg3);
    public A withNewStatusReplicasPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStatusReplicasPath(String arg1);
}
